//
//  ViewController.swift
//  SmartAxis_AddLabelsRunTime
//
//  Created by Max Rivlin on 5/9/16.
//  Copyright © 2016 Infragistics. All rights reserved.
//

import UIKit
import IGChart

class ViewController: UIViewController, IGChartViewDelegate {

    var _chart: IGChartView!
    var _series: IGLineSeries!
    var _xAxis: IGCategoryXAxis!
    var _yAxis: IGNumericYAxis!
    var _dsh: IGCategorySeriesDataSourceHelper!
    var _data: NSMutableArray!
    var _dateFormatter: NSDateFormatter = NSDateFormatter()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        _dateFormatter.dateStyle = NSDateFormatterStyle.ShortStyle
        _dateFormatter.timeStyle = NSDateFormatterStyle.MediumStyle
        
        _data = NSMutableArray()
        
        _dsh = IGCategorySeriesDataSourceHelper(data: _data as [AnyObject], andValuePath: "value")
        _dsh.labelPath = "label"
        
        _chart = IGChartView(frame: self.view.bounds)
        _chart.autoresizingMask = [UIViewAutoresizing.FlexibleWidth, UIViewAutoresizing.FlexibleHeight]
        _chart.delegate = self
        _chart.horizontalAutoMargin = 50
        
        _xAxis = IGCategoryXAxis(key: "x")
        _yAxis = IGNumericYAxis(key: "y")
        
        _xAxis.useSmartAxisPanel = true
        _xAxis.smartAxisAngle = 30
        _xAxis.smartAxisFontSize = 12
        
        _yAxis.minimum = 0
        _yAxis.maximum = 100
        
        _chart.addAxis(_xAxis)
        _chart.addAxis(_yAxis)
        
        _series = IGLineSeries(key: "series")
        _series.xAxis = _xAxis
        _series.yAxis = _yAxis
        _series.dataSource = _dsh
        
        _chart.addSeries(_series)
        
        self.view.addSubview(_chart)

        NSTimer.scheduledTimerWithTimeInterval(1, target: self, selector: #selector(tick), userInfo: nil, repeats: false)
    }

    func tick()
    {
        for _ in 0..<10
        {
            let value: CGFloat = CGFloat(arc4random()%10 + 70)
            let timestamp: NSDate = NSDate(timeIntervalSinceNow: 0)
            let label: String = _dateFormatter.stringFromDate(timestamp)
            
            let obj: ChartData = ChartData(value: value, timestamp: timestamp, label: label)
            _data.addObject(obj)
        }
        _dsh = IGCategorySeriesDataSourceHelper(data: _data as [AnyObject], andValuePath: "value")
        _dsh.labelPath = "label"
        _series.dataSource = _dsh
        
//        let value: CGFloat = CGFloat(arc4random()%10 + 70)
//        let timestamp: NSDate = NSDate(timeIntervalSinceNow: 0)
//        let label: String = _dateFormatter.stringFromDate(timestamp)
//        
//        let obj: ChartData = ChartData(value: value, timestamp: timestamp, label: label)
//        _data.addObject(obj)
//        _dsh.data = _data as [AnyObject]
//        
//        _chart.insertItemAtIndex(_series.dataPoints.count, withSource: _dsh)
    }
}

class ChartData: NSObject
{
    var value: CGFloat = 0
    var timestamp: NSDate
    var label: String

    init(value: CGFloat, timestamp: NSDate, label: String) {
       self.value = value
        self.timestamp = timestamp
        self.label = label
    }
}